package cn.net.communal.cpzshandset.service.presenter.impl.setting.sheepEx;

import java.util.ArrayList;
import java.util.List;

import android.app.ProgressDialog;
import android.content.Context;
import android.content.Intent;
import android.os.Handler;
import android.widget.Toast;
import cn.net.communal.cpzshandset.bean.ConfigBean;
import cn.net.communal.cpzshandset.common.bitmap.MBitmapService;
import cn.net.communal.cpzshandset.common.config.Config;
import cn.net.communal.cpzshandset.common.config.HandsetSettingOption;
import cn.net.communal.cpzshandset.common.config.HandsetVersionConstant;
import cn.net.communal.cpzshandset.common.config.RequestConstant;
import cn.net.communal.cpzshandset.common.config.SDCardConfig;
import cn.net.communal.cpzshandset.common.util.CachePut;
import cn.net.communal.cpzshandset.common.util.DateUtil;
import cn.net.communal.cpzshandset.common.util.NetWorkUtils;
import cn.net.communal.cpzshandset.service.bll.SheepDealerBll;
import cn.net.communal.cpzshandset.service.bll.ProductBll;
import cn.net.communal.cpzshandset.service.bll.TruckAddressBll;
import cn.net.communal.cpzshandset.service.bll.TruckConsigneeBll;
import cn.net.communal.cpzshandset.service.bll.TruckInvoiceBll;
import cn.net.communal.cpzshandset.service.bll.UserLoginBll;
import cn.net.communal.cpzshandset.service.bll.config.ConfigBll;
import cn.net.communal.cpzshandset.service.presenter.SettingConstact;
import cn.net.communal.cpzshandset.service.presenter.base.impl.SettingConstactImpl;
import cn.net.communal.cpzshandset.service.thread.ThreadPoolManager;
import cn.net.communal.cpzshandset.service.thread.ThreadReqTools;
import cn.net.communal.cpzshandset.service.thread.impl.sheepEx.SheepExReqDealerInfoRunable;
import cn.net.communal.cpzshandset.service.thread.impl.ythImage.DownloadImageRunable;
import cn.net.communal.cpzshandset.service.thread.impl.ythLogin.YthLoginReqTruckConsigneeRunable;
import cn.net.communal.cpzshandset.service.thread.impl.ythLogin.YthLoginReqTruckStationRunable;
import cn.net.communal.cpzshandset.service.thread.impl.ythLogin.YthLoginReqUserInfoRunable;
import cn.net.communal.cpzshandset.ui.activity.DeviceIdConfigActivity;
import cn.net.communal.cpzshandset.ui.activity.ModifyHandsetVersionActivity;
import cn.net.communal.cpzshandset.ui.adapter.SettingAdapter;
import cn.net.communal.cpzshandset.ui.weight.DialogUtils;
import cn.net.cpzslibs.prot.handset.bean.res.Prot20001ResBean;
import cn.net.cpzslibs.prot.handset.bean.res.Prot20012ResBean;
import cn.net.cpzslibs.prot.handset.bean.res.Prot20013ResBean;
import cn.net.cpzslibs.prot.handset.bean.res.Prot20020ResBean;
import cn.net.cpzslibs.prot.handset.bean.res.Prot20024ResBean;
import cn.net.handsetlib.utils.ReadDeviceIDUtil;

public class SheepExSettingPresenter extends SettingConstactImpl {
	private final SettingConstact.View sView;
	private Context context;
	private List<HandsetSettingOption> beans = new ArrayList<HandsetSettingOption>();
	private ConfigBll configBll;
	private SheepDealerBll dealerBll;
	private ProgressDialog bProgressDialog = null;
	private int currentHandsetVersion = HandsetVersionConstant.HANDSET_SHEEP_EXCHANGE_CARGO;
	private Handler mHandler = new Handler() {
		public void handleMessage(android.os.Message msg) {
			switch (msg.what) {
			case RequestConstant.REQUEST_FAIL:
				// 请求失败
				if (!checkViewAvailable())
					return;
				dismissProgress();
				sView.showMsgToast("请求失败！", Toast.LENGTH_SHORT);
				break;
			case RequestConstant.REQUEST_FAIL_SOCKET_TIMEOUT:
				// 超时
				if (!checkViewAvailable())
					return;
				dismissProgress();
				sView.showMsgToast("请求超时！", Toast.LENGTH_SHORT);
				break;
			case RequestConstant.REQUEST_PROT01_LOGIN_FAIL:
				// 登录失败
				if (!checkViewAvailable())
					return;
				dismissProgress();
				String errorMsg = msg.obj.toString();
				int errorCode = msg.arg1;
				sView.showMsgToast(errorMsg + errorCode, Toast.LENGTH_SHORT);
				break;
			case RequestConstant.PROT_REQ_DEALERINFO_20024_NO_DATA:
				// 无用户信息
				if (!checkViewAvailable())
					return;
				dismissProgress();
				sView.showMsgToast("请求成功，但未获取到经销商信息", Toast.LENGTH_SHORT);
				break;
			case RequestConstant.PROT_REQ_DEALERINFO_20024_FAIL:
				// 请求用户信息失败
				if (!checkViewAvailable())
					return;
				dismissProgress();
				Prot20024ResBean resBean1 = (Prot20024ResBean) msg.obj;
				if (resBean1 != null) {
					// res = resBean.getErrmsg()+resBean.getErrcode();
					sView.showMsgToast(
							ThreadReqTools.getErrorMsg(resBean1.getErrcode()) + "错误码：" + resBean1.getErrcode(),
							Toast.LENGTH_SHORT);
				} else {
					sView.showMsgToast("请求经销商信息失败!", Toast.LENGTH_SHORT);
				}
				break;
			case RequestConstant.PROT_REQ_DEALERINFO_20024_SUCCESS:
				// 请求用户信息成功
				if (!checkViewAvailable())
					return;
				dismissProgress();
				sView.showMsgToast("经销商信息更新成功", Toast.LENGTH_SHORT);
				break;
			}
		}

	};



	public SheepExSettingPresenter(SettingConstact.View sView, Context context) {
		this.sView = sView;
		this.context = context;
		start();
	}

	@Override
	public void start() {
		if (!checkViewAvailable())
			return;
		configBll = new ConfigBll(context);
		initSettingData();
		SettingAdapter adapter = new SettingAdapter(beans);
		sView.setAdapter(adapter);
	}

	private void initSettingData() {
		beans.add(HandsetSettingOption.SETTING_CONFIG_DEVICE_ID_MODE);
		beans.add(HandsetSettingOption.SETTING_UPDATE_AGENCY_LIST_MODE);
		if (Config.canSwitchHandsetVersionMode) {
			beans.add(HandsetSettingOption.SETTING_HANDSET_MODE_SWITCH_MODE);
		}
	}

	@Override
	public boolean checkViewAvailable() {
		boolean b = false;
		if (sView != null && context != null) {
			b = true;
		}
		return b;
	}

	@Override
	public void onActivityResult(int requestCode, int resultCode, Intent data) {

	}

	@Override
	public Handler getHandler() {
		// TODO Auto-generated method stub
		return null;
	}

	@Override
	public void onItemClickListener(int position) {
		swithSettingOption(beans.get(position));
	}

	public void dismissProgress() {
		if (bProgressDialog != null) {
			try {
				DialogUtils.dismissProgressDialog(bProgressDialog);
			} catch (Exception e) {
			}
		}
	}

	/**
	 * 提示正在更新数据
	 */
	protected void showProgressDialog(String titleStr, String tipsMsg) {
		bProgressDialog = DialogUtils.showProgressDialog(bProgressDialog, titleStr, tipsMsg, context);
	}

	@SuppressWarnings("incomplete-switch")
	private void swithSettingOption(HandsetSettingOption setOption) {
		switch (setOption) {
		case SETTING_HANDSET_MODE_SWITCH_MODE:
			// 修改手持机版本模式
			// sView.showMsgToast("修改手持机版本模式", Toast.LENGTH_SHORT);
			Intent modifyVersionIntent = new Intent(context, ModifyHandsetVersionActivity.class);
			context.startActivity(modifyVersionIntent);
			break;
		case SETTING_CONFIG_DEVICE_ID_MODE:
			// 配置设备ID
			// sView.showMsgToast("配置设备ID", Toast.LENGTH_SHORT);
			Intent intent = new Intent(context, DeviceIdConfigActivity.class);
			context.startActivity(intent);
			break;
		case SETTING_UPDATE_AGENCY_LIST_MODE:
			// 更新收货单位信息
			ConfigBean configBean2 = configBll.queryConfigByHandsetMode(currentHandsetVersion);
			if (configBean2 != null) {
				if (!NetWorkUtils.isNetworkConnected(context)) {
					DialogUtils.showSetNetDialog(context);
					return;
				}
				showProgressDialog("提示", "正在请求经销商信息，请稍后……");
				long deviceId = Long.parseLong(ReadDeviceIDUtil.readScanDecrypt(configBean2.getDeviceId()));
				ThreadPoolManager.getThreadPool().execute(new SheepExReqDealerInfoRunable(mHandler, deviceId, getDealerBll()));
			} else {
				sView.showMsgToast("当前设备还未配置过手持机id，请先配置手持机的设备id", Toast.LENGTH_SHORT);
			}
			break;
		}
	}

	private SheepDealerBll getDealerBll() {
		if(dealerBll == null) dealerBll = new SheepDealerBll(context);
		return dealerBll;
	}


}
